@@ -20,15 +20,6 @@ def getMatters(soup):
 		item = item.findNext('p')
 	return main
 
-def getDQ(soup):
-	pivot = soup.find('div', id='yd-PlugIn')
-	if not pivot:
-		pivot = soup.find('footer', class_='repost')
-	for item in pivot.find_next_siblings():
-		item.decompose()
-	pivot.decompose()
-	return soup
-
 def getUdn(soup):
 	main = soup.find("main")
 	try:
@@ -72,6 +63,7 @@ def _getInnerArticle_(soup, domain):
 		lambda x: x.find("div", class_ = "pane-node-body"),
 		lambda x: x.find("div", class_ = "info-content"),
 		lambda x: x.find("main", class_ = "info-content"),
+		lambda x: x.find("div", class_ = "post__contentWrap"),
 	]
 	domain_specific_applicators = {
 		'': [lambda x: x.find("body")],
@@ -116,8 +108,6 @@ def _getInnerArticle_(soup, domain):
 				candidate = applicator(soup)
 				if candidate:
 					soup = candidate
-	if 'dq.yam.com' in domain:
-		return getDQ(soup)
 	return soup
 
 def _getInnerArticle(soup, domain):
