@@ -32,7 +32,8 @@ OFFTOPIC_ATT = [
 	'field-photo-credit', 'Avatar', 'floating-share', 'meta-box', 'tag-list',
 	'tools__ShareIconBlock', 'aside__Container', 'MetadataAndTool', 'DesktopAsideBlock',
 	'StyledSeparationCurve', 'separation-curve', "['extending']", "['meta-tag']",
-	'sharedaddy', 'ArticleTags_root'
+	'sharedaddy', 'ArticleTags_root', 'imgWrap__nav'
+
 ]
 
 OFFTOPIC_ATT_WITH_EXCEPTION = {
@@ -104,6 +105,8 @@ def _decompseAds(soup):
 	for item in soup.find_all("p"):
 		if matchKey(item.text, P_AD_WORDS) or item.text in ['广告']:
 			_decompose(item)
+		if 'align=' in str(item) and 'right' in str(item) and item.text and item.text.startswith('文：'):
+			_decompose(item)
 
 def _decomposeOfftopic(soup, url, args = {}):
 	for item in list(soup.find_all())[1:]:
